import { request } from "@/utils/request";

// 首页统计
export function FirstPageStatistic(data) {
    return request({
        url: '/service-meeting/meetingRoom/FirstPageStatistic',
        method: 'GET',
        params: data
    })
}

// 会议室列表
export function dmMeetingRoomList(data) {
    return request({
        url: '/service-meeting/meetingRoom/dmMeetingRoomList',
        method: 'POST',
        data: data
    })
}

// 会议室下拉列表
export function MeetingRoomList(data) {
    return request({
        url: '/service-meeting/meetingRoom/MeetingRoomList',
        method: 'GET',
        params: data
    })
}



/**
 * 楼层管理api接口集合
 * @method Select 列表
 * @method Insert 新增
 * @method Update 修改
 * @method Delete 删除
 */
export function floorApi() {
    return {
        Select: (data) => {
            return request({
                url: '/service-meeting/meetingFloor/meetingFloorList',
                method: 'POST',
                data,
            });
        },
        Insert: (data) => {
            return request({
                url: '/service-meeting/meetingFloor',
                method: 'POST',
                data
            });
        },
        Update: (data) => {
            return request({
                url: '/service-meeting/meetingFloor',
                method: 'PUT',
                data
            });
        },
        Delete: (data) => {
            return request({
                url: '/service-meeting/meetingFloor?floorId=' + data,
                method: 'DELETE',
            });
        },
    };
}

/**
 * 设备管理api接口集合
 * @method Select 列表
 * @method Insert 新增
 * @method Update 修改
 * @method Delete 删除
 */
export function deviceApi() {
    return {
        Select: (data) => {
            return request({
                url: '/service-meeting/meetingDevice/meetingDeviceList',
                method: 'POST',
                data,
            });
        },
        Insert: (data) => {
            return request({
                url: '/service-meeting/meetingDevice',
                method: 'POST',
                data
            });
        },
        Update: (data) => {
            return request({
                url: '/service-meeting/meetingDevice',
                method: 'PUT',
                data
            });
        },
        Delete: (data) => {
            return request({
                url: '/service-meeting/meetingDevice?deviceId=' + data,
                method: 'DELETE',
            });
        },
    };
}


/**
 * 会议室管理api接口集合
 * @method Select 列表
 * @method Insert 新增
 * @method Update 修改
 * @method Delete 删除
 */
export function roomApi() {
    return {
        Select: (data) => {
            return request({
                url: '/service-meeting/meetingRoom/dmMeetingRoomList',
                method: 'POST',
                data,
            });
        },
        Insert: (data) => {
            return request({
                url: '/service-meeting/meetingRoom',
                method: 'POST',
                data
            });
        },
        Update: (data) => {
            return request({
                url: '/service-meeting/meetingRoom',
                method: 'PUT',
                data
            });
        },
        Delete: (data) => {
            return request({
                url: '/service-meeting/meetingRoom?roomId=' + data,
                method: 'DELETE',
            });
        },
    };
}

//会议室详情
export function meetingRoomDetails(data) {
    return request({
        url: '/service-meeting/meetingRoom/meetingRoomDetails',
        method: 'GET',
        params: data
    })
}

//会议室预约情况列表
export function MeetingRoomReservationList(data) {
    return request({
        url: '/service-meeting/meetingRoom/getMeetingRoomReservationList',
        method: 'POST',
        data: data
    })
}

//会议室预约-新增会议
export function meetingInfoAdd(data) {
    return request({
        url: '/service-meeting/meetingInfo/add',
        method: 'POST',
        data
    })
}

/**
 * 会议室记录api接口集合
 * @method Select 列表
 * @method Cancel 取消
 */
export function recordApi() {
    return {
        Select: (data) => {
            return request({
                url: '/service-meeting/meetingInfo/meetingInfoList',
                method: 'POST',
                data,
            });
        },
        Cancel: (data) => {
            return request({
                url: '/service-meeting/meetingInfo/cancel?meetingId=' + data,
                method: 'POST',
            });
        },
    };
}

/**
 * 我的会议api接口集合
 * @method Select 列表
 * @method SignList 人员签到-列表
 * @method InsertFile 会议文件-添加
 * @method SelectFile 会议文件-列表
 */
export function myApi() {
    return {
        Select: (data) => {
            return request({
                url: '/service-meeting/meetingInfo/myMeetingList',
                method: 'POST',
                data,
            });
        },
        SignList: (data) => {
            return request({
                url: '/service-meeting/meetingInfo/meetingSignList',
                method: 'GET',
                params: data
            });
        },
        InsertFile: (data) => {
            return request({
                url: '/service-meeting/meetingFile/insertMeetingFile',
                method: 'POST',
                data,
            });
        },
        SelectFile: (data) => {
            return request({
                url: '/service-meeting/meetingFile/meetingFileList',
                method: 'POST',
                data,
            });
        },
    };
}

//人员签到-人员签退
export function signOnOut(data) {
    return request({
        url: '/service-meeting/meetingInfo/signOnOut',
        method: 'POST',
        data
    })
}

//门禁开门
export function control(data) {
    return request({
        url: `/service-meeting/meetingRoom/502_KAT/223212768/control`,
        method: 'GET',
        params: data
    })
}